        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260818 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260818 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>10</strong> miembros: 27 <strong>control</strong><br>0,1,3,5,8,9,10,12,13,14,16,17,21,22,24,25,27,28,29,31,33,34,35,36,39,43,49';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260818 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>18</strong> miembros: 24 <br>2,4,6,7,11,15,18,19,20,23,26,30,32,37,38,40,41,42,44,45,46,47,48,50';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260818 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260818 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>10</strong> miembros: 27 <strong>control</strong><br>0,1,3,5,8,9,10,12,13,14,16,17,21,22,24,25,27,28,29,31,33,34,35,36,39,43,49';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260818 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>18</strong> miembros: 24 <br>2,4,6,7,11,15,18,19,20,23,26,30,32,37,38,40,41,42,44,45,46,47,48,50';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260818 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260818 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>10</strong> miembros: 27 <strong>control</strong><br>0,1,3,5,8,9,10,12,13,14,16,17,21,22,24,25,27,28,29,31,33,34,35,36,39,43,49';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260818 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>18</strong> miembros: 24 <br>2,4,6,7,11,15,18,19,20,23,26,30,32,37,38,40,41,42,44,45,46,47,48,50';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260818 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260818 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>10</strong> miembros: 27 <strong>control</strong><br>0,1,3,5,8,9,10,12,13,14,16,17,21,22,24,25,27,28,29,31,33,34,35,36,39,43,49';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260818 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>18</strong> miembros: 24 <br>2,4,6,7,11,15,18,19,20,23,26,30,32,37,38,40,41,42,44,45,46,47,48,50';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260818 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260818 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>10</strong> miembros: 27 <strong>control</strong><br>0,1,3,5,8,9,10,12,13,14,16,17,21,22,24,25,27,28,29,31,33,34,35,36,39,43,49';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260818 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>18</strong> miembros: 24 <br>2,4,6,7,11,15,18,19,20,23,26,30,32,37,38,40,41,42,44,45,46,47,48,50';}
}
